@@ -40,10 +40,10 @@ semaphore = contextvars.ContextVar('asyncio.Semaphore', default=None)
 
 class Media(object):
     """Class used to handle media."""
-    arg = Arguments()
+    args = Arguments()
 
-    _chunk_size = arg.chunk_size
-    _threshold = arg.big_file_threshold
+    _threshold = args.big_file_threshold
+    _proxy = args.proxy
 
     def __init__(self, *, url: str,
                  size: Optional[int] = 0,
@@ -86,7 +86,9 @@ class Media(object):
     async def _set_size(self) -> None:
         """set media file's real size by parsing server's response headers."""
         headers = {'range': 'bytes=0-1'}
-        async with session.get().get(url=self.url, headers=headers) as r:
+        async with session.get().get(
+            url=self.url, headers=headers, proxy=self._proxy
+        ) as r:
             self.size = int(r.headers['Content-Range'].split('/')[1])
 
     def _get_headers(self, index: Optional[int] = 0) -> dict:
@@ -142,12 +144,14 @@ class Media(object):
         headers = self._get_headers(index)  # get headers to send to server
 
         async with semaphore.get():
-            async with session.get().get(url=self.url, headers=headers) as r:
+            async with session.get().get(
+                url=self.url, headers=headers, proxy=self._proxy
+            ) as r:
                 with open(target, 'wb') as f:
-                    async for chk in r.content.iter_chunked(self._chunk_size):
-                        f.write(chk)
+                    async for chunk in r.content.iter_any():
+                        f.write(chunk)
 
-                        self._current_size += self._chunk_size
+                        self._current_size += len(chunk)
                         self._print_progress()
 
     def _print_progress(self) -> None:
@@ -155,12 +159,12 @@ class Media(object):
         progress = int(self._current_size / self.size * 20)
         print('\r', ConsoleColor.WARNING, '[downloading] ',
               ConsoleColor.OKGREEN,
-              f'[{progress*100/20:3.0f}%]',  # percent
+              f'[{self._current_size/self.size*100:3.0f}%]',  # percent
               f'({self._current_size/1024/1024:6.2f}/',  # current_size
               f'{self.size/1024/1024:6.2f}MB)|',  # total_size
               'x' * progress, '.' * (20 - progress),  # naive progress bar
-              ' ', os.path.split(self.location)[1],
-              '\r', ConsoleColor.ENDC, sep='', end='')
+              ' ', ConsoleColor.OKCYAN, os.path.split(self.location)[1],
+              ConsoleColor.ENDC, '\r', ConsoleColor.ENDC, sep='', end='')
 
 
 class MediaCollection(list):
@@ -227,13 +231,14 @@ class MediaCollection(list):
         cmd += ['-codec', 'copy', self.location, '-y']
 
         # call command provided by opration system
-        subprocess.run(cmd,
-                       stdout=subprocess.DEVNULL, stderr=subprocess.STDOUT,
-                       check=True)
-
-        # remove temporary files
-        for item in self:
-            os.remove(item.location)
+        try:
+            subprocess.run(cmd,
+                           stdout=subprocess.DEVNULL, stderr=subprocess.STDOUT,
+                           check=True)
+            for item in self:
+                os.remove(item.location)
+        except Exception:  # pylint: disable=W0703
+            info('warn', 'check your ffmpeg!')
 
     def sort_media(self, reverse: bool = True) -> None:
         """sort medias in media collection, biggest one will be the first."""
@@ -279,6 +284,9 @@ class Video(object):
             'video': MediaCollection(),  # video = picture + sound
         }
 
+        # used to hold something else
+        self.meta_data = {}
+
     def get_folder(self) -> str:
         """return video's store folder."""
         if self.parent_folder is not None and self.use_parent_folder is True:
@@ -314,7 +322,17 @@ class Video(object):
             self.media_collection['video'].sort_media()
 
             # choose from 'video' media collection
-            raise NotImplementedError('just wait!')
+            if self.interactive is False:
+                info('choose', 'using default value (the first one)...')
+                v = 1
+            else:
+                info('choose', 'please choose a video below...')
+                print(self.media_collection['video'])
+                v = ask_user(count=1, default=1)
+
+            media = self.media_collection['video'][v - 1]
+            self.media_collection['video'].clear()
+            self.add_media(media)
         else:
             # sort item in media collection
             self.media_collection['picture'].sort_media()
@@ -330,21 +348,33 @@ class Video(object):
                     print(self.media_collection[key])
                 v, a = ask_user(count=2, default=1)
 
-            info('choosed', '↓↓↓↓↓↓↓↓↓↓↓')
             self.add_media(self.media_collection['picture'][v - 1])
             self.add_media(self.media_collection['sound'][a - 1])
-            print(self.media_collection['video'])
+
+        info('choosed', '↓↓↓↓↓↓↓↓↓↓↓')
+        print(self.media_collection['video'])
+
+        # save memory
+        del self.media_collection['picture']
+        del self.media_collection['sound']
 
     async def download(self) -> None:
         """download medias contained in video media collection."""
         # create directory if necessary
         folder = self.get_folder()
         if folder != self.root_folder:
-            if os.path.exists(folder) is False or os.path.isfile(folder):
-                os.mkdir(self.get_folder())
+            if not os.path.exists(folder) or os.path.isfile(folder):
+                os.mkdir(folder)
 
         await self.media_collection['video'].download()
 
     def merge(self) -> None:
         """merge medias contained in video media collection."""
         self.media_collection['video'].merge()
+
+    def save_to_disk(self, content: str, suffix: str) -> None:
+        """save something to disk with same name but different suffix."""
+        path, _ = os.path.splitext(self.get_location())
+        path = f'{path}.{suffix}'
+        with open(path, 'w', encoding='utf-8') as f:
+            f.write(content)
